/*
 * Copyright 2018 Confluent Inc.
 *
 * Licensed under the Confluent Community License (the "License"); you may not use
 * this file except in compliance with the License.  You may obtain a copy of the
 * License at
 *
 * http://www.confluent.io/confluent-community-license
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 */

package io.confluent.kafkarest.entities;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.databind.JsonNode;

public class AvroProduceRecord extends ProduceRecordBase<JsonNode, JsonNode> {

  @JsonCreator
  public AvroProduceRecord(
      @JsonProperty("key") JsonNode key,
      @JsonProperty("value") JsonNode value
  ) {
    super(key, value);
  }

  public AvroProduceRecord(JsonNode value) {
    this(null, value);
  }

  @Override
  public JsonNode getJsonKey() {
    return key;
  }

  @Override
  public JsonNode getJsonValue() {
    return value;
  }

  @Override
  public boolean equals(Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }

    AvroProduceRecord that = (AvroProduceRecord) o;

    if (key != null ? !key.equals(that.key) : that.key != null) {
      return false;
    }
    if (value != null ? !value.equals(that.value) : that.value != null) {
      return false;
    }

    return true;
  }

  @Override
  public int hashCode() {
    int result = key != null ? key.hashCode() : 0;
    result = 31 * result + (value != null ? value.hashCode() : 0);
    return result;
  }

  public boolean hasKey() {
    return key != null && !key.isNull();
  }

  public boolean hasValue() {
    return value != null && !value.isNull();
  }
}
